using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
using Oqtane.Services;
using Oqtane.Shared;

namespace SZUAbsolventenverein.Module.EventRegistration.Services
{
    public class EventRegistrationService : ServiceBase, IEventRegistrationService
    {
        public EventRegistrationService(HttpClient http, SiteState siteState) : base(http, siteState) { }

        private string Apiurl => CreateApiUrl("EventRegistration");

        public async Task<List<Models.Event>> GetEventRegistrationsAsync(int ModuleId)
        {
            List<Models.Event> EventRegistrations = await GetJsonAsync<List<Models.Event>>(CreateAuthorizationPolicyUrl($"{Apiurl}?moduleid={ModuleId}", EntityNames.Module, ModuleId), Enumerable.Empty<Models.Event>().ToList());
            return EventRegistrations.OrderBy(item => item.Name).ToList();
        }

        public async Task<Models.Event> GetEventRegistrationAsync(int EventRegistrationId, int ModuleId)
        {
            return await GetJsonAsync<Models.Event>(CreateAuthorizationPolicyUrl($"{Apiurl}/{EventRegistrationId}/{ModuleId}", EntityNames.Module, ModuleId));
        }

        public async Task<Models.Event> AddEventRegistrationAsync(Models.Event EventRegistration)
        {
            return await PostJsonAsync<Models.Event>(CreateAuthorizationPolicyUrl($"{Apiurl}", EntityNames.Module, EventRegistration.ModuleId), EventRegistration);
        }

        public async Task<Models.Event> UpdateEventRegistrationAsync(Models.Event EventRegistration)
        {
            return await PutJsonAsync<Models.Event>(CreateAuthorizationPolicyUrl($"{Apiurl}/{EventRegistration.EventRegistrationId}", EntityNames.Module, EventRegistration.ModuleId), EventRegistration);
        }

        public async Task DeleteEventRegistrationAsync(int EventRegistrationId, int ModuleId)
        {
            await DeleteAsync(CreateAuthorizationPolicyUrl($"{Apiurl}/{EventRegistrationId}/{ModuleId}", EntityNames.Module, ModuleId));
        }
    }
}
